@@ -19,15 +19,15 @@ ENTITIES = {
 
 def correspsearch(correspondent=None, sender=None, addressee=None,
                   startdate=None, enddate=None, place=None,
-                  placeSender=None, placeAddressee=None,
+                  placeSender=None, placeAddressee=None, publication=None,
                   available=None, strictDate=False, endpoint=TEI_XML):
     """
     | query data in CMI format via correspSearch API by given parameters
     | available endpoints: TEI_XML (default) / TEI_JSON
     | see https://correspsearch.net/index.xql?id=api for details
     """
-    if correspondent == sender == addressee and sender is None:
-        print("specify correspondent, sender or addressee!")
+    if correspondent == sender == addressee == publication and sender is None:
+        print("specify correspondent, sender, addressee or publication!")
         return None
     params = {}
     if correspondent is not None:
@@ -36,6 +36,9 @@ def correspsearch(correspondent=None, sender=None, addressee=None,
         params["sender"] = sender
     if addressee is not None:
         params["addressee"] = addressee
+    if publication is not None:
+        params["correspondent"] = "all"
+        params["publication"] = publication
     if startdate is not None:
         params["startdate"] = startdate
     if enddate is not None:
